<p align="center">
  <a href="https://docsify.js.org">
    <img alt="docsify" src="./assets/sastrapy.svg">
  </a>
</p>
<p align="center">
 🖌 Sastrapy - Teman sastramu.
</p>

<p align="center">
<a href="https://github.com/sastrapy/sastrapy/blob/master/LICENSE"><img alt="license" src="https://img.shields.io/github/license/docsifyjs/docsify-cli.svg?style=flat-square"></a>
<a href="https://github.com/sastrapy/sastrapy"><img alt="repo-code-size" src="https://img.shields.io/github/languages/code-size/sastrapy/sastrapy?style=flat-square"></a>
<a href="https://pypi.org/project/Sastrapy/"><img alt="version" src="https://img.shields.io/pypi/v/sastrapy?style=flat-square"></a>
<a href="https://pypi.org/project/Sastrapy/"><img alt="downloads" src="https://img.shields.io/pypi/dw/sastrapy?style=flat-square"></a>
</p>

# Sastrapy
Sastrapy adalah pengolah teks sederhana untuk Bahasa Indonesia. Sastrapy berisi beberapa metode seperti slang converter, tokenize, stopword remover, dan kami berharap di masa depan Sastrapy memiliki fungsi stemming.

# Tujuan pembuatan
Tujuan pembuatan dari library Sastrapy adalah berangkat dari kebutuhan dalam text processing dalam Bahasa Indonesia yang semakin hari bahasa yang digunakan di tengah masyarakat semakin beragam. Munculnya istilah baru, singkatan baru, dan gaya penulisan baru membuat sebuah library text processing harus beradaptasi. Di sini Sastrapy berusaha untuk memberikan kemudahan dalam adaptasi tersebut.

# Dokumentasi
Semua dokumentasi sudah dikumpulkan di https://sastrapy.github.io
